==> 3.5.1.tar.gz: xbackbone/resources/lang/pl.lang.php <==
<?php
return [
    'lang' => 'Polish',
    'yes' => 'Tak',
    'no' => 'Nie',
    'send' => 'Wyślij',
    'no_media' => 'Nie znaleziono plików.',
    'login.username' => 'Nazwa użytkownika lub e-mail',
    'password' => 'Hasło',
    'login' => 'Login',
    'username' => 'Nazwa użytkownika',
    'users' => 'Użytkownicy',
    'system' => 'System',
    'profile' => 'Profil',
    'logout' => 'Wyloguj',
    'pager.next' => 'Następna',
    'pager.previous' => 'Poprzednia',
    'copy_link' => 'Skopiuj link',
    'public.telegram' => 'Udostępnij na Telegram',
    'public.delete_text' => 'Jesteś pewien, że chcesz usunąć ten element? Nie będzie możliwości odzyskania go',
    'delete' => 'Usuń',
    'hide' => 'Ukryj',
    'files' => 'Pliki',
    'click_to_load' => 'Kliknij, aby załadować...',
    'apply' => 'Zastosuj',
    'save' => 'Zapisz',
    'system_info' => 'Informacje o systemie',
    'user.create' => 'Utwórz Użytkownika',
    'user.edit' => 'Edytuj użytkownika',
    'is_active' => 'Jest aktywny',
    'your_profile' => 'Twój profil',
    'token' => 'Token',
    'copy' => 'Kopiuj',
    'edit' => 'Edytuj',
    'client_config' => 'Konfiguracja Klienta',
    'user_code' => 'Kod użytkownika',
    'active' => 'Aktywny',
    'admin' => 'Admin',
    'reg_date' => 'Data rejestracji',
    'open' => 'Otwórz',
    'confirm' => 'Potwierdzenie',
    'confirm_string' => 'Jesteś pewien?',
    'installed' => 'Instalacja zakończona pomyślnie!',
    'welcome' => 'Witaj, %s!',
    'email_required' => 'Adres e-mail jest wymagany.',
    'username_required' => 'Nazwa użytkownika jest wymagana.',
    'username_taken' => 'Nazwa użytkownika jest już zajęta.',
    'password_required' => 'Hasło jest wymagane.',
    'user_created' => 'Użytkownik „%s” utworzony!',
    'profile_updated' => 'Profil zaktualizowany pomyślnie!',
    'enforce_language' => 'Wymuś język',
    'home' => 'Strona główna',
    'preview' => 'Podgląd',
    'filename' => 'Nazwa pliku',
    'size' => 'Rozmiar',
    'public' => 'Publiczny',
    'owner' => 'Właściciel',
    'date' => 'Data',
    'raw' => 'Pokaż bez formatowania',
    'download' => 'Pobierz',
    'upload' => 'Prześlij',
    'publish' => 'Opublikuj',
    'orphaned_files' => 'Porzucone Pliki',
    'theme' => 'Motyw',
    'used' => 'Wykorzystano',
    'is_admin' => 'Jest administratorem',
    'update' => 'Zaktualizuj',
    'none' => 'Żaden',
    'bad_login' => 'Błędne dane uwierzytelniające.',
    'account_disabled' => 'Twoje konto jest wyłączone.',
    'goodbye' => 'Do zobaczenia!',
    'token_not_found' => 'Nie znaleziono określonego tokena.',
    'email_taken' => 'Ten adres e-mail jest już zajęty.',
    'user_updated' => 'Użytkownik „%s” zaktualizowany!',
    'user_deleted' => 'Użytkownik usunięty.',
    'cannot_delete' => 'Nie możesz usunąć siebie.',
    'cannot_demote' => 'Nie możesz siebie zdegradować.',
    'cannot_write_file' => 'Ścieżka docelowa nie jest zapisywalna.',
    'deleted_orphans' => 'Pomyślnie usunięto %d porzuconych plików.',
    'switch_to' => 'Przełącz na',
    'gallery' => 'Galeria',
    'table' => 'Tabela',
    'dotted_search' => 'Szukaj...',
    'order_by' => 'Sortuj...',
    'time' => 'Czas',
    'name' => 'Nazwa',
    'maintenance' => 'Konserwacja',
    'clean_orphaned_uploads' => 'Wyczyść porzucone pliki',
    'path_not_writable' => 'Ścieżka wyjściowa nie jest zapisywalna.',
    'already_latest_version' => 'Masz już najnowszą wersję.',
    'new_version_available' => 'Nowa wersja %s dostępna!',
    'cannot_retrieve_file' => 'Nie można pobrać pliku.',
    'file_size_no_match' => 'Pobrany plik nie pasuje do odpowiedniego rozmiaru pliku.',
    'check_for_updates' => 'Sprawdź aktualizacje',
    'upgrade' => 'Aktualizuj',
    'updates' => 'Aktualizacje',
    'maintenance_in_progress' => 'Platforma w trakcie konserwacji, spróbuj ponownie później...',
    'cancel' => 'Anuluj',
    'auto_set' => 'Ustaw automatycznie',
    'default_lang_behavior' => 'XBackBone domyślnie spróbuje dopasować język przeglądarki (zastępczym jest Angielski).',
    'lang_set' => 'Wymuszono język systemu na "%s"',
    'prerelease_channel' => 'Kanał Prerelease',
    'no_upload_token' => 'Nie masz osobistego tokena przesyłania. (Wygeneruj jeden i spróbuj ponownie.)',
    'drop_to_upload' => 'Kliknij lub upuść swoje pliki tutaj, aby przesłać.',
    'donation' => 'Darowizna',
    'donate_text' => 'Jeśli podoba Ci się XBackBone, rozważ darowiznę na wsparcie rozwoju!',
    'custom_head_html' => 'Niestandardowa zawartość Head (HTML)',
    'custom_head_html_hint' => 'Ta zawartość zostanie dodana pod tagiem <head> na każdej stronie.',
    'custom_head_set' => 'Zastosowano niestandardową zawartość dla elementu head (HTML).',
    'remember_me' => 'Zapamiętaj mnie',
    'please_wait' => 'Proszę czekać…',
    'dont_close' => 'Nie zamykaj tej zakładki do czasu ukończenia.',
    'php_info' => 'Informacje PHP',
    'system_settings' => 'Ustawienia systemu',
    'register_enabled' => 'Rejestracje włączone',
    'hide_by_default' => 'Domyślnie ukrywaj pliki',
    'copy_url_behavior' => 'Tryb kopiowania URL',
    'settings_saved' => 'Zapisano ustawienia systemu!',
    'export_data' => 'Eksportuj dane',
    'password_recovery' => 'Odzyskaj hasło',
    'no_account' => 'Nie posiadasz konta?',
    'register' => 'Rejestracja',
    'default_user_quota' => 'Domyślny przydział użytkownika',
    'invalid_quota' => 'Nieprawidłowe wartości jako domyślny przydział użytkownika.',
    'register_success' => 'Konto zostało utworzone, e-mail potwierdzający został wysłany.',
    'mail.activate_account' => '%s - Aktywacja konta',
    'mail.recover_password' => '%s - Odzyskiwanie hasła',
    'recover_email_sent' => 'Jeżeli istnieje, wiadomość e-mail do odzyskiwania hasła została wysłane na określone konto.',
    'account_activated' => 'Konto aktywowane, teraz możesz się zalogować!',
    'quota_enabled' => 'Włącz przydział użytkownika',
    'password_repeat' => 'Powtórz hasło',
    'password_match' => 'Hasło i powtórzone hasło muszą być takie same.',
    'password_restored' => 'Zresetowanie hasła.',
    'recalculate_user_quota' => 'Przelicz przydział użytkownika z dysku',
    'quota_recalculated' => 'Pomyślnie przeliczono z dysku przydział użytkownika.',
    'used_space' => 'Użyte miejsce',
    'max_user_quota' => 'Maksymalny przydział użytkownika',
    'delete_selected' => 'Usuń zaznaczone',
    'delete_all' => 'Usuń wszystko',
    'clear_account' => 'Wyczyść konto',
    'account_media_deleted' => 'Wszystkie pliki na koncie zostały usunięte.',
    'danger_zone' => 'Niebezpieczne',
    'recaptcha_failed' => 'reCAPTCHA nieudana',
    'recaptcha_enabled' => 'reCAPTCHA włączona',
    'recaptcha_keys_required' => 'Wszystkie klucze reCAPTCHA są wymagane.',
    'only_recaptcha_v3' => 'Tylko reCAPTCHA v3 jest obsługiwana.',
    'recaptcha_site_key' => 'Klucz strony reCAPTCHA',
    'recaptcha_secret_key' => 'Sekretny klucz reCAPTCHA',
    'send_notification' => 'Wyślij powiadomienie e-mail',
    'auto_tagging' => 'Automatyczne tagowanie po przesłaniu',
    'no_tags' => 'Nie dodano tagów',
    'upload_max_file_size' => 'Obecnie maksymalny rozmiar pliku wynosi %s.',
    'ldap_cant_connect' => 'Nie można połączyć z serwerem uwierzytelniającym LDAP.',
    'user_create_password' => 'Jeśli pozostawiono puste, możesz wysłać powiadomienie na adres e-mail użytkownika.',
    'mail.new_account' => '%s - Tworzenie nowego konta',
    'show_changelog' => 'Pokaż dziennik zmian',
    'changelog' => 'Dziennik zmian',
    'zip_ext_not_loaded' => 'Wymagane rozszerzenie zip nie jest załadowane',
    'mail.new_account_text_with_pw' => 'Cześć %s!<br>zostało utworzone nowe konto dla Ciebie na %s (<a href="%s">%s</a>), z następującymi danymi logowania:<br><br>Nazwa użytkownika: %s<br>Hasło: %s<br><br>Kliknij w poniższy link, aby przejść na stronę logowania:<br><a href="%s">%s</a>',
    'mail.new_account_text_with_reset' => 'Cześć %s!<br>zostało utworzone nowe konto dla Ciebie na %s (<a href="%s">%s</a>), kliknij w poniższy link aby ustawić hasło i aktywować je:<br><br><a href="%s">%s</a>',
    'mail.recover_text' => 'Cześć %s,<br>została wysłana prośba o zresetowanie hasła do twojego konta. Aby zakończyć procedurę, kliknij w poniższy link:<br><br><a href="%s">%s</a><br><br>Jeśli to nie ty poprosiłeś o zresetowanie hasła, po prostu zignoruj ten e-mail.',
    'mail.activate_text' => 'Cześć %s!<br>dziękuję za utworzenie konta na %s (<a href="%s">%s</a>), kliknij w poniższy link, aby je aktywować:<br><br><a href="%s">%s</a>',
];

==> 3.6.2.tar.gz: xbackbone/resources/lang/pl.lang.php <==
<?php
return [
    'lang' => 'Polish',
    'yes' => 'Tak',
    'no' => 'Nie',
    'send' => 'Wyślij',
    'no_media' => 'Nie znaleziono plików.',
    'login.username' => 'Nazwa użytkownika lub e-mail',
    'password' => 'Hasło',
    'login' => 'Login',
    'username' => 'Nazwa użytkownika',
    'users' => 'Użytkownicy',
    'system' => 'System',
    'profile' => 'Profil',
    'logout' => 'Wyloguj',
    'pager.next' => 'Następna',
    'pager.previous' => 'Poprzednia',
    'copy_link' => 'Skopiuj link',
    'public.telegram' => 'Udostępnij na Telegram',
    'public.delete_text' => 'Jesteś pewien, że chcesz usunąć ten element? Nie będzie możliwości odzyskania go',
    'delete' => 'Usuń',
    'hide' => 'Ukryj',
    'files' => 'Pliki',
    'click_to_load' => 'Kliknij, aby załadować…',
    'apply' => 'Zastosuj',
    'save' => 'Zapisz',
    'system_info' => 'Informacje o systemie',
    'user.create' => 'Utwórz Użytkownika',
    'user.edit' => 'Edytuj użytkownika',
    'is_active' => 'Jest aktywny',
    'your_profile' => 'Twój profil',
    'token' => 'Token',
    'copy' => 'Kopiuj',
    'edit' => 'Edytuj',
    'client_config' => 'Konfiguracja Klienta',
    'user_code' => 'Kod użytkownika',
    'active' => 'Aktywny',
    'admin' => 'Admin',
    'reg_date' => 'Data rejestracji',
    'open' => 'Otwórz',
    'confirm' => 'Potwierdzenie',
    'confirm_string' => 'Jesteś pewien?',
    'installed' => 'Instalacja zakończona pomyślnie!',
    'welcome' => 'Witaj, %s!',
    'email_required' => 'Adres e-mail jest wymagany.',
    'username_required' => 'Nazwa użytkownika jest wymagana.',
    'username_taken' => 'Nazwa użytkownika jest już zajęta.',
    'password_required' => 'Hasło jest wymagane.',
    'user_created' => 'Użytkownik „%s” utworzony!',
    'profile_updated' => 'Profil zaktualizowany pomyślnie!',
    'enforce_language' => 'Wymuś język',
    'home' => 'Strona główna',
    'preview' => 'Podgląd',
    'filename' => 'Nazwa pliku',
    'size' => 'Rozmiar',
    'public' => 'Publiczny',
    'owner' => 'Właściciel',
    'date' => 'Data',
    'raw' => 'Pokaż bez formatowania',
    'download' => 'Pobierz',
    'upload' => 'Prześlij',
    'publish' => 'Opublikuj',
    'orphaned_files' => 'Porzucone Pliki',
    'theme' => 'Motyw',
    'used' => 'Wykorzystano',
    'is_admin' => 'Jest administratorem',
    'update' => 'Zaktualizuj',
    'none' => 'Żaden',
    'bad_login' => 'Błędne dane uwierzytelniające.',
    'account_disabled' => 'Twoje konto jest wyłączone.',
    'goodbye' => 'Do zobaczenia!',
    'token_not_found' => 'Nie znaleziono określonego tokena.',
    'email_taken' => 'Ten adres e-mail jest już zajęty.',
    'user_updated' => 'Użytkownik „%s” zaktualizowany!',
    'user_deleted' => 'Użytkownik usunięty.',
    'cannot_delete' => 'Nie możesz usunąć siebie.',
    'cannot_demote' => 'Nie możesz siebie zdegradować.',
    'cannot_write_file' => 'Ścieżka docelowa nie jest zapisywalna.',
    'deleted_orphans' => 'Pomyślnie usunięto %d porzuconych plików.',
    'switch_to' => 'Przełącz na',
    'gallery' => 'Galeria',
    'table' => 'Tabela',
    'dotted_search' => 'Szukaj…',
    'order_by' => 'Sortuj…',
    'time' => 'Czas',
    'name' => 'Nazwa',
    'maintenance' => 'Konserwacja',
    'clean_orphaned_uploads' => 'Wyczyść porzucone pliki',
    'path_not_writable' => 'Ścieżka wyjściowa nie jest zapisywalna.',
    'already_latest_version' => 'Masz już najnowszą wersję.',
    'new_version_available' => 'Nowa wersja %s dostępna!',
    'cannot_retrieve_file' => 'Nie można pobrać pliku.',
    'file_size_no_match' => 'Pobrany plik nie pasuje do odpowiedniego rozmiaru pliku.',
    'check_for_updates' => 'Sprawdź aktualizacje',
    'upgrade' => 'Aktualizuj',
    'updates' => 'Aktualizacje',
    'maintenance_in_progress' => 'Trwają prace techniczne, spróbuj ponownie później…',
    'cancel' => 'Anuluj',
    'auto_set' => 'Ustaw automatycznie',
    'default_lang_behavior' => 'XBackBone domyślnie spróbuje dopasować język przeglądarki (zastępczym jest Angielski).',
    'lang_set' => 'Wymuszono język systemu na "%s"',
    'prerelease_channel' => 'Kanał Prerelease',
    'no_upload_token' => 'Nie masz osobistego tokena przesyłania. (Wygeneruj jeden i spróbuj ponownie.)',
    'drop_to_upload' => 'Kliknij lub upuść swoje pliki tutaj, aby przesłać.',
    'donation' => 'Darowizna',
    'donate_text' => 'Jeśli podoba Ci się XBackBone, rozważ darowiznę na wsparcie rozwoju!',
    'custom_head_html' => 'Niestandardowa zawartość Head (HTML)',
    'custom_head_html_hint' => 'Ta zawartość zostanie dodana pod tagiem <head> na każdej stronie.',
    'custom_head_set' => 'Zastosowano niestandardową zawartość dla elementu head (HTML).',
    'remember_me' => 'Zapamiętaj mnie',
    'please_wait' => 'Proszę czekać…',
    'dont_close' => 'Nie zamykaj tej zakładki do czasu ukończenia.',
    'php_info' => 'Informacje PHP',
    'system_settings' => 'Ustawienia systemu',
    'register_enabled' => 'Rejestracje włączone',
    'hide_by_default' => 'Domyślnie ukrywaj pliki',
    'copy_url_behavior' => 'Tryb kopiowania URL',
    'settings_saved' => 'Zapisano ustawienia systemu!',
    'export_data' => 'Eksportuj dane',
    'password_recovery' => 'Odzyskaj hasło',
    'no_account' => 'Nie posiadasz konta?',
    'register' => 'Rejestracja',
    'default_user_quota' => 'Domyślny przydział użytkownika',
    'invalid_quota' => 'Nieprawidłowe wartości jako domyślny przydział użytkownika.',
    'register_success' => 'Konto zostało utworzone, e-mail potwierdzający został wysłany.',
    'mail.activate_account' => '%s - Aktywacja konta',
    'mail.recover_password' => '%s - Odzyskiwanie hasła',
    'recover_email_sent' => 'Jeżeli istnieje, wiadomość e-mail do odzyskiwania hasła została wysłane na określone konto.',
    'account_activated' => 'Konto aktywowane, teraz możesz się zalogować!',
    'quota_enabled' => 'Włącz przydział użytkownika',
    'password_repeat' => 'Powtórz hasło',
    'password_match' => 'Hasło i powtórzone hasło muszą być takie same.',
    'password_restored' => 'Zresetowanie hasła.',
    'recalculate_user_quota' => 'Przelicz przydział użytkownika z dysku',
    'quota_recalculated' => 'Pomyślnie przeliczono z dysku przydział użytkownika.',
    'used_space' => 'Użyte miejsce',
    'max_user_quota' => 'Maksymalny przydział użytkownika',
    'delete_selected' => 'Usuń zaznaczone',
    'delete_all' => 'Usuń wszystko',
    'clear_account' => 'Wyczyść konto',
    'account_media_deleted' => 'Wszystkie pliki na koncie zostały usunięte.',
    'danger_zone' => 'Niebezpieczne',
    'recaptcha_failed' => 'reCAPTCHA nieudana',
    'recaptcha_enabled' => 'reCAPTCHA włączona',
    'recaptcha_keys_required' => 'Wszystkie klucze reCAPTCHA są wymagane.',
    'only_recaptcha_v3' => 'Tylko reCAPTCHA v3 jest obsługiwana.',
    'recaptcha_site_key' => 'Klucz strony reCAPTCHA',
    'recaptcha_secret_key' => 'Sekretny klucz reCAPTCHA',
    'send_notification' => 'Wyślij powiadomienie e-mail',
    'auto_tagging' => 'Automatyczne tagowanie po przesłaniu',
    'no_tags' => 'Nie dodano tagów',
    'upload_max_file_size' => 'Obecnie maksymalny rozmiar pliku wynosi %s.',
    'ldap_cant_connect' => 'Nie można połączyć z serwerem uwierzytelniającym LDAP.',
    'user_create_password' => 'Jeśli pozostawiono puste, możesz wysłać powiadomienie na adres e-mail użytkownika.',
    'mail.new_account' => '%s - Tworzenie nowego konta',
    'show_changelog' => 'Pokaż dziennik zmian',
    'changelog' => 'Dziennik zmian',
    'zip_ext_not_loaded' => 'Wymagane rozszerzenie zip nie jest załadowane',
    'mail.new_account_text_with_pw' => 'Cześć %s!<br>zostało utworzone nowe konto dla Ciebie na %s (<a href="%s">%s</a>), z następującymi danymi logowania:<br><br>Nazwa użytkownika: %s<br>Hasło: %s<br><br>Kliknij w poniższy link, aby przejść na stronę logowania:<br><a href="%s">%s</a>',
    'mail.new_account_text_with_reset' => 'Cześć %s!<br>zostało utworzone nowe konto dla Ciebie na %s (<a href="%s">%s</a>), kliknij w poniższy link aby ustawić hasło i aktywować je:<br><br><a href="%s">%s</a>',
    'mail.recover_text' => 'Cześć %s,<br>została wysłana prośba o zresetowanie hasła do twojego konta. Aby zakończyć procedurę, kliknij w poniższy link:<br><br><a href="%s">%s</a><br><br>Jeśli to nie ty poprosiłeś o zresetowanie hasła, po prostu zignoruj ten e-mail.',
    'mail.activate_text' => 'Cześć %s!<br>dziękuję za utworzenie konta na %s (<a href="%s">%s</a>), kliknij w poniższy link, aby je aktywować:<br><br><a href="%s">%s</a>',
    'image_embeds' => 'Osadź obrazy',
    'copied' => 'Skopiowano!',
];
